

## Grid

### Bug Fixes

- `246248` - Script error thrown when DataSource is null and while performing search in the `MultiSelect` component has been resolved.
- `F146875` - Multiple checkbox selection is not working when `rowSelected` event is used in `blazor` grid has been resolved.
- `243156` - Data is not getting updated for first time on external action has been resolved.
- `F146396` - Template column is not displayed when its `DataType` is TimeSpan has been resolved.
- `F146078` - Unable to use read-only properties inside column template is resolved
- Script error has been fixed while using `rowSelected` event.
- Column dataSource provided as `WebAPIAdpator` was converted to `BlazorAdaptor` during initial rendering has been fixed.
- `F146980` - Incorrect GUID filter query string generation is now resolved.
- `240240`, `245760` - conditional formatting is not applied properly to all the columns has been resolved.
- `F146668` - Dictionary values are not properly serialized in grid templates has been resolved.

### Features

- Data annotation support has been added. Now you can use various attributes to define grid column and other options. More information can be find [here](https://ej2.syncfusion.com/blazor/documentation/grid/data-annotation/).

### Breaking Changes

- Now you can define filter column declaratively. Also now use `GridFilterColumn` instead of `PredicateModel`.
  
**Previous**
 
```csharp
 
@{
 List<PredicateModel> FilterColumns = new List<PredicateModel>();
 FilterColumns.Add(new PredicateModel() { Field = "CustomerID", Operator = Operator.StartsWith, Value = "ANANTR" });
}
<EjsGrid DataSource="@Orders" AllowFiltering="true">
 <GridFilterSettings Columns="@FilterColumns"></GridFilterSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp
<EjsGrid DataSource="@Orders" AllowFiltering="true">
 <GridFilterSettings>
 <GridFilterColumns>
 <GridFilterColumn Field="CustomerID" Value="@("A")" Operator=Operator.StartsWith>
 </GridFilterColumn>
 </GridFilterColumns>
 </GridFilterSettings> 
 ...
 </EjsGrid> 

```
 
- Now you can define filter column declaratively. Also now use `GridSortColumn` instead of `SortDescriptorModel`.
 
**Previous**
 
```csharp
 
@{
 List<SortDescriptorModel> SortedColumns = new List<SortDescriptorModel>();
 SortedColumns.Add(new SortDescriptorModel() { Field = "OrderDate", Direction = SortDirection.Ascending });
 SortedColumns.Add(new SortDescriptorModel() { Field = "Freight", Direction = SortDirection.Descending });
}
<EjsGrid DataSource="@Orders" AllowSorting="true">
 <GridSortSettings Columns="@SortedColumns"></GridSortSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp
<EjsGrid DataSource="@Orders" AllowSorting="true">
 <GridSortSettings>
 <GridSortColumns>
 <GridSortColumn Field="OrderDate" Direction=SortDirection.Ascending>
 </GridSortColumn>
 <GridSortColumn Field="Freight" Direction=SortDirection.Descending>
 </GridSortColumn>
 </GridSortColumns>
 </GridSortSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
- Now you can define command column declaratively. Also now use `GridCommandColumn` instead of `CommandModel`.
 
**Previous**
 
```csharp
 
@{
 List<CommandModel> Commands = new List<CommandModel>();
 Commands.Add(new CommandModel() { Type = CommandButtonType.Edit, ButtonOption = new CommandButtonOptions() { IconCss = "e-icons e-edit", CssClass = "e-flat" } });
 Commands.Add(new CommandModel() { Type = CommandButtonType.Delete, ButtonOption = new CommandButtonOptions() { IconCss = "e-icons e-delete", CssClass = "e-flat" } });
 Commands.Add(new CommandModel() { Type = CommandButtonType.Save, ButtonOption = new CommandButtonOptions() { IconCss = "e-icons e-save", CssClass = "e-flat" } });
 Commands.Add(new CommandModel() { Type = CommandButtonType.Cancel, ButtonOption = new CommandButtonOptions() { IconCss = "e-icons e-cancel", CssClass = "e-flat" } });
}
 
<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn HeaderText="Manage Records" Commands="@Commands" Width="150"></GridColumn>
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp
<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn HeaderText="Manage Records" Width="150">
 <GridCommandColumns>
 <GridCommandColumn Type="CommandButtonType.Edit" ButtonOption="@(new CommandButtonOptions() { IconCss = "e-icons e-edit", CssClass = "e-flat" })"></GridCommandColumn>
 <GridCommandColumn Type="CommandButtonType.Delete" ButtonOption="@(new CommandButtonOptions() { IconCss = "e-icons e-delete", CssClass = "e-flat" })"></GridCommandColumn>
 <GridCommandColumn Type="CommandButtonType.Save" ButtonOption="@(new CommandButtonOptions() { IconCss = "e-icons e-update", CssClass = "e-flat" })"></GridCommandColumn>
 <GridCommandColumn Type="CommandButtonType.Cancel" ButtonOption="@(new CommandButtonOptions() { IconCss = "e-icons e-cancel-icon", CssClass = "e-flat" })"></GridCommandColumn>
 </GridCommandColumns>
 </GridColumn>
 </GridColumns>
</EjsGrid>
 
```

- The type of `EditType` property in `GridColumn` is modified from string type to Enum type.
 
**Previous**
 
```csharp

<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn Field=@nameof(OrdersDetails.OrderDate) EditType="date"></GridColumn>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp
<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn Field=@nameof(OrdersDetails.OrderDate) EditType=EditType.Date></GridColumn>
 ...
 </GridColumns>
</EjsGrid>
```

- The `Type` property in `GridColumn` is modified from string type to Enum type.
 
**Previous**
 
```csharp

<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn Field=@nameof(OrdersDetails.OrderDate) Type="date"></GridColumn>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp
<EjsGrid DataSource="@Orders">
 <GridColumns>
 ...
 <GridColumn Field=@nameof(OrdersDetails.OrderDate) Type=ColumnType.Date></GridColumn>
 ...
 </GridColumns>
</EjsGrid>
```

- The `Operator` property in `GridFilterSettings` is modified from string type to Enum type.
 
**Previous**
 
```csharp
 
@{
 List<PredicateModel> FilterColumns = new List<PredicateModel>();
 FilterColumns.Add(new PredicateModel() { Field = "CustomerID", Operator = "StartsWith", Value = "ANANTR" });
}
<EjsGrid DataSource="@Orders" AllowFiltering="true">
 <GridFilterSettings Columns="@FilterColumns"></GridFilterSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```cshtml
@using Syncfusion.EJ2.Blazor

<EjsGrid DataSource="@Orders" AllowFiltering="true">
 <GridFilterSettings>
 <GridFilterColumns>
 <GridFilterColumn Field="CustomerID" Value="@("ANANTR")" Operator=Operator.StartsWith>
 </GridFilterColumn>
 </GridFilterColumns>
 </GridFilterSettings> 
 ...
 </EjsGrid> 

```
- The `Operator` property in `GridSearchSettings` is modified from string type to Enum type.
 
**Previous**
 
```csharp
 
<EjsGrid DataSource="@Orders">
 <GridSearchSettings Fields="@(new string[] { "CustomerID" })" Operator="Contains" Key="anton"></GridSearchSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>
 
```
 
**Now**
 
```csharp

@using Syncfusion.EJ2.Blazor

<EjsGrid DataSource="@Orders">
 <GridSearchSettings Fields="@(new string[] { "CustomerID" })" Operator= Operator.Contains Key="anton"></GridSearchSettings>
 <GridColumns>
 ...
 </GridColumns>
</EjsGrid>

```

