## Common

### Bug Fixes

- `#F148260`, `#257111` - Fixed the XSS vulnerability issue for ASP.NET Core Components.

## Bullet Chart

Bullet Chart is the variation of bar chart, which displays one or more measures, and compares it to a target value. You can also display the measures in a qualitative range of performance such as poor, satisfactory, or good. All stock elements are rendered by using Scalable Vector Graphics (SVG).


- **Data Binding** - Binds the data with local and remote data source.
- **Animation** - Feature and target bar will be animated when rendering.
- **Tooltip** - Supports tooltip for the feature and target bar.
- **Orientation** - Supports vertical and horizontal rendering.
- **Flow Direction** - Supports to render from right to left.
- **Multiple Target** - Supports multiple targets.
- **Data Labels** - Supports data label to enhance the data.

## Chart

### Bug Fixes

- `#256664` - Polar and radar axis labels overlapping with legend issue fixed.
- `#149497` - Axis labels are invalid when using label format as percentage in stacking 100 percent series types issue fixed.

## Chips

### Bug Fixes

- `#250583` - Now, the selected chips values are maintained after selecting and deselecting the chips.

## DashboardLayout

### New Features

- The content template support has been provided in the Dashboard Layout panel property.

## DateRangePicker

### Bug Fixes

- `#252163` - Issue with "pre-selected value sent to the server with wrong date format while changing the culture dynamically" has been resolved.

## Document Editor

### New Features

- `#249197`, `#249364`, `#148274`, `#253325` Added support for converting SFDT to Word document in server side.
- `#125563`, `#158324`, `#210401`, `#231575`, `#239871`, `#238529`, `#240405`, `#252988`, `#255850` - Added support for insert and edit comments.
- `#245203` - Added support for section pages field.
- `#255626`,`#254750` - RTL and locale is now updated properly on property change.
- `#251866` - Enhancement for Auto list feature.

## HeatMap

### New Features

- `#234060`, `#246529` - Provided the cell color customization support for heatmap by using the `cellRender` event .
- Provided the legend title support to customize the legend title in heatmap.
- Provided the support for a cell color range to customize a cell color based on the range value.

## PDF Viewer

### Bug Fixes

- `#253751` – Resolved the typo error in annotation exported data.
- `#255345` – Errors will no longer occur while rendering the annotation in the Firefox browser.
- `#255137` – Errors will no longer occur in mobile view mode if we set the Pan interaction mode.
- `#253704` – The form fields are downloaded properly while loading the PDF document in tab control.
- `#253745` – The annotationAdd and annotationPropertiesChange events are triggered properly for the annotations.
- `#252881` – The toolbar settings property is working for mobile device.
- `#255042`, `#255073` – Errors will no longer occur if the session storage exceeds the maximum limit.
- `#254115`, `#254942` – The annotation modified date is preserved properly in different localization.
- `#256044` – The font family and text alignment are rendered properly from the exported FreeText annotation data.
- `#255124` – The text markup annotations are now added properly if the PDF Viewer element ID contains characters.
- `#256220` – The context menu will now be shown/hidden properly if we disable the default toolbar.
- `#256131` – The annotation toolbar will now be shown/hidden properly if we disable the annotation toolbar.
- `#256932` - Errors will no longer occur while resizing the text markup annotations.
- `#252805` – The annotationId value is now preserved properly for all annotation events.
- `#255647` - The form fields contents are rendered properly in the printed document, which has been printed in IE browser.

### New Features

- `#251150` – Provided the support to find the interlinked annotations while selecting the annotations.
- `#243077` , `#241487`, `#244802`, `#252340` – Provided the support for setting the annotation UI properties.
- `#254634` – Provided the support to maintain the aspect ratio for custom stamp annotation.
- `#253745`, `#256518` – Exposed the event to notify the annotation object being moved.
- `#254275` – Exposed the event to notify the download process in the PDF Viewer control.

## Pivot Table

### Bug Fixes

- `#254586` - The conditional formatting will no longer be applied in empty cells.
- The summarization text `of` in value buttons inside grouping bar and field list layout can be localized now.

### New Features

- `#252636` - Provision provided to disable the scrollbars in pivot chart.
- `#250072` - Provision provided to group and separate the grouped headers through UI.

## RangeNavigator

### Bug Fixes

- `#255451` - Label alignment issue in range navigator has been fixed.

## RichTextEditor

### New Features

- **Callback event to custom toolbar**: The feature allows to bind click event handler to the custom toolbar items in the Rich Text Editor.
- **Code format as toolbar button**: Provided an option to add the code format as toolbar button with toggle state in the Rich Text Editor.
- **XHTML validation**: Provided support to validate the content of Rich Text Editor with XHTML standard.

## Splitter

### New Features

- `#251791` - Provided the support to use DOM element as pane content by configuring the selector to the content of `paneSettings` property.

## Spreadsheet

### Breaking Changes

- Tag directive changed for below properties.

Collection properties:


| Property | Old Tag Directive | New Tag Directive | 
|---|---|---|
| Sheets | `<e-sheets>`<br/>`<e-sheet>` | `<e-spreadsheet-sheets>`<br/>`<e-spreadsheet-sheet>` | 
| Rows | `<e-rows>`<br/>`<e-row>` | `<e-spreadsheet-rows>`<br/>`<e-spreadsheet-row>` | 
| cells | `<e-cells>`<br/>`<e-cell>` | `<e-spreadsheet-cells>`<br/>`<e-spreadsheet-cell>` | 
| Columns | `<e-columns>`<br/>`<e-column>` | `<e-spreadsheet-columns>`<br/>`<e-spreadsheet-column>` | 
| RangeSettings | `<e-rangesettings>`<br/>`<e-rangesetting>` | `<e-spreadsheet-rangesettings>`<br/>`<e-spreadsheet-rangesetting>` | 
| DefinedNames | `<e-definednames>`<br/>`<e-definedname>` | `<e-spreadsheet-definednames>`<br/>`<e-spreadsheet-definedname>` | 

Complex properties:


| Style | `<e-style>` | `<e-spreadsheet-cellstyle>` | 
| UsedRange | `<e-usedrange>` | `<e-spreadsheet-usedrange>` | 
| CellStyle | `<e-cellstyle>` | `<e-spreadsheet-cellstyle>` | 
| ScrollSettings | `<e-scrollsettings>` | `<e-spreadsheet-scrollsettings>` | 
| SelectionSettings | `<e-selectionsettings>` | `<e-spreadsheet-selectionsettings>` | 


## Toast

### New Features

- `252807` - Provided the support to access the 'dynamic toast model properties passed in the show method', as arguments in the `beforeOpen`, `open` and `close` events.

## TreeGrid

### Breaking Changes

- Default value of column's `disableHtmlEncode` is set to true, so the HTML tags can be displayed in the Grid header and content by default. To display it as html content `disableHtmlEncode` need to be set as false.

### New Features

- AutoFill support has been provided that allows users to copy the data of selected cells and paste it to another cells by dragging.

## TreeView

### New Features

- `#249238` - Provided the support for refreshing a specific node in tree view.
- `#253508` - Now, the `actionFailure` event triggers while fetching data from the invalid path.
- `#247333` - Support has been provided to get the disabled nodes in the tree view.

## Visual Studio extensions

### New Features

- Enhanced the user experience by including Visual Studio Scaffolding templates for Grid, Chart, Schedule, Diagram, Tree Grid, Rich Text Editor, Document Editor, and PDF Viewer.
- Upgraded the .NET Core 3.1 project templates.

